@@ -1,6 +1,6 @@
 r"""
-Custom PDE: Brusselator
-=======================
+Custom PDE class: Brusselator
+=============================
 
 This example implements the `Brusselator 
 <https://en.wikipedia.org/wiki/Brusselator>`_ with spatial coupling,
@@ -12,6 +12,10 @@ This example implements the `Brusselator
     
 Here, :math:`D_0` and :math:`D_1` are the respective diffusivity and the
 parameters :math:`a` and :math:`b` are related to reaction rates.
+
+Note that the PDE can also be implemented using the :class:`~pde.pdes.pde.PDE`
+class; see :doc:`the example <pde_brusselator>`. However, that implementation
+is less flexible and might be more difficult to extend later.
 """
 
 import numpy as np
