@@ -1197,7 +1197,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         
     @fill_in_docstring
     def get_boundary_values(self, axis: int,
-                            upper: bool = True,
+                            upper: bool,
                             bc: BoundariesData = 'natural') -> np.ndarray:
         """ get the field values directly on the specified boundary 
         
@@ -1219,7 +1219,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         
     @fill_in_docstring
     def make_get_boundary_values(self, axis: int,
-                                 upper: bool = True,
+                                 upper: bool,
                                  bc: BoundariesData = 'natural') -> np.ndarray:
         """ make a function calculating field values on the specified boundary 
         
@@ -1242,8 +1242,11 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         interpolator = self.make_interpolator(bc=bc)
         points = self.grid._boundary_coordinates(axis, upper)
         
+        # TODO: use jit_allocated_out with pre-calculated shape
+        
         @jit
-        def inner(data: np.ndarray = None, out: np.ndarray = None):
+        def get_boundary_values(data: np.ndarray = None,
+                                out: np.ndarray = None):
             """ interpolate the field at the boundary
             
             Args:
@@ -1261,10 +1264,12 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             if out is None:
                 return res
             else:
-                out[:] = res
+                # the following just copies the data from res to out. It is a
+                # workaround for a bug in numba existing up to at least ver 0.49
+                out[...] = res[()]
                 return out
             
-        return inner
+        return get_boundary_values
         
         
     def apply(self: TDataField, func: Callable,
@@ -1297,7 +1302,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
     def integral(self) -> Union[np.ndarray, float]: pass 
     
     @abstractmethod
-    def to_scalar(self, scalar: Union[str, int] = 'norm',
+    def to_scalar(self, scalar: str = 'auto',
                   label: Optional[str] = None) -> "ScalarField": pass
                   
                   
@@ -1611,6 +1616,21 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         finalize_plot(ax, title=title, filename=filename, show=show)
             
         return res
+    
+    
+    def plot_interactive(self, scalar: str = 'auto', **kwargs):
+        """ create an interactive plot of the field using :mod:`napari`
+        
+        Args:
+            scalar (str): The method for obtaining scalar values of fields        
+            **kwargs: Extra arguments are passed to :class:`napari.Viewer`
+        """
+        from ..visualization.plotting import napari_viewer
+        with napari_viewer(self.grid, **kwargs) as viewer:
+            viewer.add_image(self.to_scalar(scalar).data,
+                             name=self.label,
+                             rgb=False,
+                             scale=self.grid.discretization)
 
 
     def plot(self, kind: str = 'auto', **kwargs):
@@ -1619,8 +1639,8 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         Args:
             kind (str):
                 Determines the visualizations. Supported values are `image`, 
-                `line`, or `vector`. Alternatively, `auto` determines the best
-                visualization based on the field itself.
+                `line`, `vector`, or `interactive`. Alternatively, `auto`
+                determines the best visualization based on the field itself.
             \**kwargs:
                 All additional keyword arguments are forwarded to the actual
                 plotting functions. This includes `ax` to determine the
@@ -1650,6 +1670,8 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             res = self.plot_line(**kwargs)
         elif kind == 'vector':
             res = self.plot_vector(**kwargs)
+        elif kind == 'interactive':
+            res = self.plot_interactive(**kwargs)
         else:
             raise ValueError(f'Unsupported plot `{kind}`. Possible choices are '
                              '`image`, `line`, `vector`, or `auto`.')
