@@ -178,9 +178,8 @@ class BCBase(metaclass=ABCMeta):
 
     _subclasses: Dict[str, 'BCBase'] = {}  # all classes inheriting from this
     _conditions: Dict[str, 'BCBase'] = {}  # mapping from all names to classes
-    
 
-    _value: Union[float, np.ndarray]
+    _value: np.ndarray
     
 
     @fill_in_docstring    
@@ -188,7 +187,7 @@ class BCBase(metaclass=ABCMeta):
                  axis: int,
                  upper: bool,
                  rank: int = 0,
-                 value: Union[float, np.ndarray] = 0):
+                 value: Union[float, np.ndarray, str] = 0):
         """ 
         Warning:
             {WARNING_EXEC} However, the function is safe when `value` cannot be
@@ -237,27 +236,25 @@ class BCBase(metaclass=ABCMeta):
             for name in cls.names:
                 cls._conditions[name] = cls
 
-                
-    @property
-    def value(self) -> Union[float, np.ndarray]:
-        return self._value
-                
-          
-    @value.setter  # type: ignore
+
     @fill_in_docstring          
-    def value(self, value: Union[float, np.ndarray] = 0):
-        """ set the value of this boundary condition
+    def _parse_value(self, value: Union[float, np.ndarray, str]) -> np.ndarray:
+        """ parses a boundary value
         
         Warning:
             {WARNING_EXEC}
         
         Args:
-            value (float or str or array):
-                a value stored with the boundary condition. The interpretation
-                of this value depends on the type of boundary condition.
+            value (array-like or str):
+                The value given as a array of tensorial character and optionally
+                dependent on space (along the boundary). Alternatively, a string
+                can specify a mathematical expression that can optionally depend
+                on the coordinates along the boundary. This expression is only
+                supported for scalar boundary conditions.
+                
+        Returns:
+            :class:`numpy.ndarray`: The value at the boundary
         """
-        self._value_expression = value
-        
         if isinstance(value, str):
             # inhomogeneous value given by an expression 
             if self.rank != 0:
@@ -265,7 +262,6 @@ class BCBase(metaclass=ABCMeta):
                                           'only supported for scalar values.')
             
             from ...tools.expressions import ScalarExpression
-            self.homogeneous = False
 
             # determine which coordinates are allowed to vary            
             axes_ids = (list(range(self.axis)) +
@@ -284,42 +280,79 @@ class BCBase(metaclass=ABCMeta):
             # iterate explicitly over all points because the expression might
             # not depend on some of the variables, but we still want the array
             # self._value to contain a value at each boundary point
-            self._value = np.empty_like(bc_coords[0])
+            result = np.empty_like(bc_coords[0])
             coords = {name: 0 for name in bc_vars}
-            for idx in np.ndindex(*self._value.shape):
+            for idx in np.ndindex(*result.shape):
                 for i, name in enumerate(bc_vars):
                     coords[name] = bc_coords[i][idx]
-                self._value[idx] = expr(**coords)
+                result[idx] = expr(**coords)
             
         elif np.isscalar(value):
-            # homogeneous, scalar value
-            self.homogeneous = True
-            self._value = float(value)
+            # scalar value applied to all positions
+            result = np.broadcast_to(float(value), self._shape_tensor)
             
         else:
             # assume tensorial and/or inhomogeneous values
             value = np.asarray(value, dtype=np.double)
-            shape = self._shape_tensor + self._shape_boundary
             
             if value.ndim == 0:
-                # value is a scalar, although np.isscalar(np.array(0)) == False
-                self.homogeneous = True
-                self._value = np.broadcast_to(value, self._shape_tensor)
-                    
-            elif value.shape == shape:
+                # value is a scalar
+                result = np.broadcast_to(value, self._shape_tensor)
+            elif value.shape == self._shape_tensor + self._shape_boundary:
                 # inhomogeneous field with all tensor components
-                self.homogeneous = False
-                self._value = value
-            
+                result = value
             elif value.shape == self._shape_tensor:
                 # homogeneous field with all tensor components
-                self.homogeneous = True
-                self._value = value
-                    
+                result = value
             else:
                 raise ValueError(f"Dimensions {value.shape} of the value are "
                                  f"incompatible with rank {self.rank} and "
                                  f"spatial dimensions {self._shape_boundary}.")
+                
+        # check consistency
+        if np.any(np.isnan(result)):
+            try:
+                logger = self._logger
+            except AttributeError:
+                # this can happen when _parse_value is called before the object
+                # is fully initialized
+                logger = logging.getLogger(self.__class__.__name__)
+            logger.warning('In valid values in %s', self)
+                
+        return result
+    
+                
+    @property
+    def value(self) -> np.ndarray:
+        return self._value
+                
+          
+    @value.setter  # type: ignore
+    @fill_in_docstring
+    def value(self, value: Union[float, np.ndarray, str] = 0):
+        """ set the value of this boundary condition
+        
+        Warning:
+            {WARNING_EXEC}
+        
+        Args:
+            value (float or str or array):
+                a value stored with the boundary condition. The interpretation
+                of this value depends on the type of boundary condition.
+        """
+        self._value = self._parse_value(value)
+    
+        if self._value.shape == self._shape_tensor:
+            # value does not depend on space
+            self.homogeneous = True
+        elif self._value.shape == self._shape_tensor + self._shape_boundary:
+            # inhomogeneous field
+            self.homogeneous = False
+        else:
+            raise ValueError(f"Dimensions {self._value.shape} of the value are "
+                             f"incompatible with rank {self.rank} and "
+                             f"spatial dimensions {self._shape_boundary}.")
+        
         self.value_is_linked = False
     
     
@@ -352,20 +385,15 @@ class BCBase(metaclass=ABCMeta):
             If the address of self.value changes, a new function needs to be
             created by calling this factory function again.
         """
+        # obtain details about the array
+        mem_addr = self.value.ctypes.data
+        shape = self.value.shape
+        dtype = self.value.dtype
         
-        value = self.value
-        if not isinstance(value, np.ndarray):
-            RuntimeError('self.value must be a `numpy.ndarray` for creating '
-                         'a value getter.')
-        
-        # obtains memory address of array
-        mem_addr = value.ctypes.data  # type: ignore
-        
-        @nb.jit(nb.typeof(value)(), inline='always')
+        @nb.jit(nb.typeof(self.value)(), inline='always')
         def get_value():
             """ helper function returning the linked array """
-            return nb.carray(address_as_void_pointer(mem_addr),
-                             value.shape, value.dtype)
+            return nb.carray(address_as_void_pointer(mem_addr), shape, dtype)
         
         return get_value  # type: ignore
         
@@ -429,12 +457,10 @@ class BCBase(metaclass=ABCMeta):
     def _cache_hash(self) -> int:
         """ returns a value to determine when a cache needs to be updated """ 
         if self.value_is_linked:
-            value = self.value.ctypes.data  # type: ignore
-        elif isinstance(self.value, np.ndarray):
-            value = self.value.tobytes()
+            value = self.value.ctypes.data
         else:
-            value = self.value
-
+            value = self.value.tobytes()
+        
         return hash((self.__class__.__name__,
                      self.grid._cache_hash(),
                      self.axis,
@@ -455,12 +481,6 @@ class BCBase(metaclass=ABCMeta):
         return obj
         
         
-    @property
-    def is_scalar(self) -> bool:
-        """ bool: whether the boundary condition is a scalar """
-        return self.rank == 0
-    
-
     def extract_component(self, *indices):
         """ extracts the boundary conditions for the given component
 
@@ -468,21 +488,8 @@ class BCBase(metaclass=ABCMeta):
             *indices:
                 One or two indices for vector or tensor fields, respectively
         """
-        if not self.homogeneous:
-            raise NotImplementedError('Only homogeneous boundary conditions '
-                                      'support tensorial values')
-            
-        if np.array_equal(self.value, 0):  # special case for all ranks
-            value = 0
-            
-        elif len(indices) == 0:  # scalar conditions
-            value = self.value
-            
-        else:  # tensorial boundary conditions
-            value = self.value[indices]
-            
-        rank = self.rank - len(indices)
-        return self.copy(value=value, rank=rank)
+        return self.copy(value=self.value[indices],
+                         rank=self.rank - len(indices))
 
                 
     @classmethod
@@ -552,30 +559,14 @@ class BCBase(metaclass=ABCMeta):
         data = data.copy()  # need to make a copy since we modify it below
         
         # parse all possible variants that could be given
-        if data.keys() == {'value'}:
-            # only a value is given => Assume Dirichlet conditions
-            b_type = 'value'
-            b_value = data.pop('value')
-            
-        elif data.keys() == {'derivative'}:
-            # the derivative is obviously given => Assume Neumann conditions
-            b_type = 'derivative'
-            b_value = data.pop('derivative')
-            
-        elif data.keys() == {'mixed'}:
-            # short notation for mixed condition
-            b_type = 'mixed'
-            b_value = data.pop('mixed')
-            
-        elif data.keys() == {'curvature'}:
-            # short notation for curvature condition
-            b_type = 'curvature'
-            b_value = data.pop('curvature')
-            
-        elif 'type' in data.keys():
+        if 'type' in data.keys():
             # type is given (optionally with a value)
             b_type = data.pop('type')
             b_value = data.pop('value', 0)
+
+        elif len(data) == 1:
+            # only a single items is given
+            b_type, b_value = data.popitem()
             
         else:
             raise ValueError('Boundary condition defined by '
@@ -620,6 +611,10 @@ class BCBase(metaclass=ABCMeta):
             # already in the correct format
             assert data.grid == grid and data.axis == axis and data.rank == rank
             return data.copy(upper=upper)
+
+        elif data == 'natural':
+            # special case of a vanishing derivative
+            return DirichletBC(grid, axis, upper=upper, rank=rank)
         
         elif isinstance(data, dict):
             # create from dictionary
@@ -709,12 +704,13 @@ class BCBase1stOrder(BCBase):
         """ calculate the value of the virtual point outside the boundary 
         
         Args:
-            arr (array): The data values associated with the grid
-            idx (tuple): The index of the point to evaluate. This is a tuple of
-                length `grid.num_axes` with the either -1 or `dim` as the entry
-                for the axis associated with this boundary condition. Here,
-                `dim` is the dimension of the axis. The index is optional if
-                dim == 1.                 
+            arr (array):
+                The data values associated with the grid
+            idx (tuple):
+                The index of the point to evaluate. This is a tuple of length
+                `grid.num_axes` with the either -1 or `dim` as the entry for the
+                axis associated with this boundary condition. Here, `dim` is the
+                dimension of the axis. The index is optional if dim == 1.                 
             
         Returns:
             float: Value at the virtual support point
@@ -875,7 +871,7 @@ class DirichletBC(BCBase1stOrder):
         index = self.grid.shape[self.axis] - 1 if self.upper else 0
             
         if not compiled:
-            factor = -1 if np.isscalar(const) else -np.ones_like(const)
+            factor = -np.ones_like(const)
             return (const, factor, index)
         else:
             # return boundary data such that dynamically calculated values can
@@ -939,7 +935,7 @@ class NeumannBC(BCBase1stOrder):
         index = self.grid.shape[self.axis] - 1 if self.upper else 0
             
         if not compiled:
-            factor = 1 if np.isscalar(const) else np.ones_like(const)
+            factor = np.ones_like(const)
             return (const, factor, index)
         else:
             # return boundary data such that dynamically calculated values can
@@ -1007,8 +1003,8 @@ class MixedBC(BCBase1stOrder):
                  axis: int,
                  upper: bool,
                  rank: int = 0,
-                 value=0,
-                 const: float = 0):
+                 value: Union[float, np.ndarray, str] = 0,
+                 const: Union[float, np.ndarray, str] = 0):
         r""" 
         Args:
             grid (:class:`~pde.grids.GridBase`):
@@ -1030,14 +1026,13 @@ class MixedBC(BCBase1stOrder):
                 value is applied to all points.  Inhomogeneous boundary
                 conditions are possible by supplying an expression as a string,
                 which then may depend on the axes names of the respective grid.
-            const (float):
+            const (float or :class:`~numpy.ndarray` or str):
                 The parameter :math:`\beta` determining the constant term for 
-                the boundary condition. This term does not yet allow for
-                tensorial or spatially varying values.
+                the boundary condition. Supports the same input as `value`.
         """
         super().__init__(grid, axis, upper, rank, value)
-        # TODO: support spatially varying constant terms β
-        self.const = float(const)  
+        self.const = self._parse_value(const)  
+        
         
     def __eq__(self, other):
         """ checks for equality neglecting the `upper` property """
@@ -1048,11 +1043,7 @@ class MixedBC(BCBase1stOrder):
 
     def _cache_hash(self) -> int:
         """ returns a value to determine when a cache needs to be updated """ 
-        if isinstance(self.const, np.ndarray):
-            const = self.const.tobytes()
-        else:
-            const = self.const  
-        return hash((super()._cache_hash(), const))
+        return hash((super()._cache_hash(), self.const.tobytes()))
     
     
     def copy(self, upper: Optional[bool] = None,
@@ -1085,23 +1076,15 @@ class MixedBC(BCBase1stOrder):
             :class:`BC1stOrderData`: the data structure associated with this
             virtual point
         """        
+        # calculate values assuming finite factor
         dx = self.grid.discretization[self.axis]
+        with np.errstate(invalid='ignore'):
+            const = np.asarray(2 * dx * self.const / (2 + dx * self.value))
+            factor = np.asarray((2 - dx * self.value) / (2 + dx * self.value))
         
-        factor = dx * self.value
-        if np.isscalar(factor):
-            if np.isinf(factor):
-                const = 0
-                factor = -1
-            else:
-                const = 2 * dx * self.const / (2 + factor)
-                factor = (2 - factor) / (2 + factor)
-        else:
-            # calculate values assuming finite factor
-            const = 2 * dx * self.const / (2 + factor)
-            factor = (2 - factor) / (2 + factor)
-            # correct at places of infinite values 
-            const[np.isinf(factor)] = 0  # type: ignore
-            factor[np.isinf(factor)] = -1
+        # correct at places of infinite values 
+        const[~np.isfinite(factor)] = 0
+        factor[~np.isfinite(factor)] = -1
             
         index = self.grid.shape[self.axis] - 1 if self.upper else 0
 
@@ -1112,7 +1095,6 @@ class MixedBC(BCBase1stOrder):
         # be used in numba compiled code. This is a work-around since numpy
         # arrays are copied into closures, making them compile-time
         # constants
-
         if self.value_is_linked:
             const_val = np.array(self.const, np.double)
             value_func = self._make_value_getter()
@@ -1203,12 +1185,13 @@ class BCBase2ndOrder(BCBase):
         """ calculate the value of the virtual point outside the boundary 
         
         Args:
-            arr (array): The data values associated with the grid
-            idx (tuple): The index of the point to evaluate. This is a tuple of
-                length `grid.num_axes` with the either -1 or `dim` as the entry
-                for the axis associated with this boundary condition. Here,
-                `dim` is the dimension of the axis. The index is optional if
-                dim == 1.                 
+            arr (array):
+                The data values associated with the grid
+            idx (tuple):
+                The index of the point to evaluate. This is a tuple of length
+                `grid.num_axes` with the either -1 or `dim` as the entry for the
+                axis associated with this boundary condition. Here, `dim` is the
+                dimension of the axis. The index is optional if dim == 1.                 
             
         Returns:
             float: Value at the virtual support point
@@ -1312,12 +1295,11 @@ class BCBase2ndOrder(BCBase):
         # calculate necessary constants
         data_vp = self.get_virtual_point_data()
         
+        zeros = np.zeros_like(self.value)
+        ones = np.ones_like(self.value)
+        
         if self.homogeneous:
             # the boundary condition does not depend on space
-            if self.is_scalar:
-                zeros = 0.
-            else:
-                zeros = np.zeros((self.grid.dim,) * self.rank)
             
             @register_jitable
             def adjacent_point(arr_1d, i_point, bc_idx):
@@ -1326,7 +1308,7 @@ class BCBase2ndOrder(BCBase):
                 if i_point == i_bndry:
                     data = data_vp
                 else:
-                    data = (zeros, 1., i_point + i_dx, 0., 0)
+                    data = (zeros, ones, i_point + i_dx, zeros, 0)
                 
                 # calculate the values
                 return (data[0] +
@@ -1335,10 +1317,6 @@ class BCBase2ndOrder(BCBase):
                 
         else:
             # the boundary condition is a function of space
-            shape = tuple(self.grid.shape[i]
-                          for i in range(self.grid.num_axes)
-                          if i != self.axis)
-            zeros, ones = np.zeros(shape), np.ones(shape)
             
             @register_jitable
             def adjacent_point(arr_1d, i_point, bc_idx):
@@ -1385,7 +1363,7 @@ class ExtrapolateBC(BCBase2ndOrder):
         else:
             i1 = 0
             i2 = 1
-        return (0., 2., i1, -1., i2)
+        return (np.array(0.), np.array(2.), i1, np.array(-1.), i2)
 
 
 
@@ -1409,12 +1387,11 @@ class CurvatureBC(BCBase2ndOrder):
             raise RuntimeError('Need at least 2 support points to use the '
                                'curvature boundary condition.')
 
-        value = self.value * dx**2
-        ones = 1 if np.isscalar(value) else np.ones_like(value)
+        value = np.asarray(self.value * dx**2)
+        f1 = np.full_like(value, 2.)
+        f2 = np.full_like(value, -1.)
         if self.upper:
-            f1, i1 = 2., size - 1
-            f2, i2 = -1., size - 2
+            i1, i2 = size - 1, size - 2
         else:
-            f1, i1 = 2., 0
-            f2, i2 = -1., 1
-        return (value, f1 * ones, i1, f2 * ones, i2)
+            i1, i2 = 0, 1
+        return (value, f1, i1, f2, i2)
